% PredatorPreyExample.m
% Solving Ordinary Differential Equations Using MATLAB
% Example #2
% -------------------------------------------------------------------------
% Author: John Pitre
% Date:   Oct 2013
% -------------------------------------------------------------------------
% This program was developed for the Fundamental Engineering Skills
% Workshop series of the University of Michigan student chapter of the American 
% Society for Engineering Education (ASEE). For more information, see our
% website www.asee.engin.umich.edu. We hope you'll learn something from
% downloading and working with this script.
% -------------------------------------------------------------------------

clear all
close all
clc


% MODEL PARAMETERS
% b : growth rate of prey in absence of predators, [1/day]
% p : predation rate, [1/(day*predator)]
% r : growth rate of predators, [1/(day*prey)]
% d : death rate of predators, [1/day]
b = 1;
p = 0.05;
r = 0.02;
d = 0.5;


% TIMESTEPPING
tspan = [0 40]; %[days]


% INITIAL CONDITIONS
% Let pp = (x y) = (prey predators).
pp0 = [10 10]; %[prey predators]


% SOLVER
% The ODE for the predator-prey system is defined in the function file
% 'PredatorPreyODE.m'. The closed brackets ([]) allow us to pass the
% parameters b, p, r, and d to the function file.
% Recall that pp = (x y) = (prey predators)
[t,pp] = ode45('PredatorPreyODE',tspan,pp0,[],b,p,r,d);


% PLOT RESULTS
figure
hold on
grid on
plot(t,pp(:,1),'b') % prey
plot(t,pp(:,2),'r') % predators
title('Lotka-Volterra Model')
legend('Prey','Predators')
xlabel('t')
ylabel('Population')