function dppdt = PredatorPreyODE(t,pp,flag,b,p,r,d)
% PredatorPreyODE defines the system of first order differential equations
% that govern the predator-prey Lotka-Volterra model.
% ---
% Solving Ordinary Differential Equations Using MATLAB
% Example #2
% -------------------------------------------------------------------------
% Author: John Pitre
% Date:   Oct 2013
% -------------------------------------------------------------------------
% This program was developed for the Fundamental Engineering Skills
% Workshop series of the University of Michigan student chapter of the American 
% Society for Engineering Education (ASEE). For more information, see our
% website www.asee.engin.umich.edu. We hope you'll learn something from
% downloading and working with this script.
% -------------------------------------------------------------------------

    % Set up storage and variable definitions. Remember that g = (x y).
    dppdt = zeros(2,1); % Preallocate to guarantee a column vector
    x = pp(1); % prey
    y = pp(2); % predators
    
    
    % Define the differential equations from the Lotka-Volterra model
    dxdt = (b - p*y)*x;
    dydt = (r*x - d)*y;
    
    
    % Store the two equations as entries of a vector.
    dppdt(1) = dxdt;
    dppdt(2) = dydt;
end