% SpringMassDamperExample2.m
% Solving Ordinary Differential Equations Using MATLAB
% Example #3
% -------------------------------------------------------------------------
% Author: John Pitre
% Date:   Oct 2013
% ---
% Note:   
% This file is identical to SpringMassDamperExample.m except it includes a 
% 'for' loop to solve for multiple damping values. We then use a neat little 
% trick to plot all of the lines on a colormap and add a colorbar to 
% differentiate them.
% -------------------------------------------------------------------------
% This program was developed for the Fundamental Engineering Skills
% Workshop series of the University of Michigan student chapter of the American 
% Society for Engineering Education (ASEE). For more information, see our
% website www.asee.engin.umich.edu. We hope you'll learn something from
% downloading and working with this script.
% -------------------------------------------------------------------------

clear all
close all
clc


% MECHANICAL PARAMETERS
% Edit these parameters to experiment with changes to the response of the
% mechanical system to some force applied to the mass. In particular, raise
% and lower the damping coefficient c to examine the effect damping has on
% the solution.
% k : spring constant, [N/m]
% c : damping coefficient, [(N/m)*s]
% m : mass, [kg]
k = 30; 
c = 0:5:30;  
m = 5; 


% TIMESTEPPING PARAMETERS
% All units are seconds
tStart = 0;
tEnd = 20;
% tStep = 0.01;              % Uncomment to use fixed timesteps
% tspan = tStart:tStep:tEnd; % "                              "
tspan = [tStart tEnd];       % Comment to use fixed timesteps


% INITIAL CONDITIONS
% Let y = dxdt and g = (x y). Then dgdt = (dxdt dydt).
g0 = [0 0]; % [m m/s]


% SET UP PLOT
% This allows sets up the plot with axis labels, title, etc. It also
% creates the plotColors vector which takes values from the colormap 'jet'.
% Each value of c is assigned a unique color from the colormap and the
% colorbar axis is set to run from the lowest to the highest value of c.
figure
hold on
grid on
title('Spring-Mass-Damper System')
xlabel('Time (s)')
ylabel('Displacement (m)')
plotColors = colormap( jet(length(c)) );
colorbar
caxis([min(c) max(c)])


% ODE SOLVER
% Let y = dxdt and g = (x y). Then dgdt = (dxdt dydt).
% The ODE for the spring-mass-damper system is defined in the function file
% 'SpringMassDamperODE.m'. The closed brackets ([]) allow us to pass the
% parameters k, c, and m to the function file.
for index = 1:length(c)
    [t,g] = ode45('SpringMassDamperODE',tspan,g0,[],k,c(index),m);
    plot(t,g(:,1),'Color',plotColors(index,:)) % plot x = g(1)
end