function dgdt = SpringMassDamperODE(t,g,flag,k,c,m)
% SpringMassDamperODE defines the system of first order differential
% equations that governs the behavior of a spring-mass-damper system in
% response to a forcing function 'force.m'.
% ---
% Solving Ordinary Differential Equations Using MATLAB
% Example #3
% -------------------------------------------------------------------------
% Author: John Pitre
% Date:   Oct 2013
% -------------------------------------------------------------------------
% This program was developed for the Fundamental Engineering Skills
% Workshop series of the University of Michigan student chapter of the American 
% Society for Engineering Education (ASEE). For more information, see our
% website www.asee.engin.umich.edu. We hope you'll learn something from
% downloading and working with this script.
% -------------------------------------------------------------------------

    % Set up storage and variable definitions. Remember that g = (x y).
    dgdt = zeros(2,1); % Preallocate to guarantee a column vector
    x = g(1);
    y = g(2);
    
    
    % Define the two first order equations. Note that these result from
    % rewriting the second order displacement equation which we obtained by
    % summing the forces on the mass.
    dxdt = y;
    dydt = -(k/m)*x - (c/m)*y + (1/m)*force(t);
    
    
    % Store the two equations as entries of a vector.
    dgdt(1) = dxdt;
    dgdt(2) = dydt;
end